#include "epuck_aggregation_loop_functions.h"
#include <argos3/core/simulator/simulator.h>
#include <argos3/core/utility/configuration/argos_configuration.h>
#include <argos3/plugins/robots/e-puck/simulator/epuck_entity.h>
#include <controllers/epuck_aggregation/epuck_aggregation.h>
#include <argos3/plugins/simulator/media/led_medium.h>

/****************************************/
/****************************************/

CEpuckAggregationLoopFunctions::CEpuckAggregationLoopFunctions() :
   m_pcFloor(NULL),
   m_pcRNG(NULL) {
}

/****************************************/
/****************************************/

void CEpuckAggregationLoopFunctions::Init(TConfigurationNode& t_node) {
   m_pcFloor = &GetSpace().GetFloorEntity();

   CLEDMedium& cLEDMedium = GetSimulator().GetMedium<CLEDMedium>("leds");

    CBoxEntity* pcBox = new CBoxEntity("box1",                  // id
                                       CVector3(1.0, 2.0, 0.0), // position
                                       CQuaternion(),           // orientation
                                       true,                    // movable or not?
                                       CVector3(0.5, 0.5, 0.5), // size
                                       1.0);                    // mass in kg
    // Add the box to the simulation
    AddEntity(*pcBox);
    // Enable LED management for the box
    pcBox->EnableLEDs(cLEDMedium);
    // Add LED on top of the box
    pcBox->AddLED(CVector3(0.0, 0.0, 1.0), // offset
                  CColor::RED);            // color
}

/****************************************/
/****************************************/

//void CEpuckAggregationLoopFunctions::Initialize() {
/* Distribute uniformly the items in the environment */
//    CLEDMedium& cLEDMedium = GetSimulator().GetMedium<CLEDMedium>("leds");
//    for(UInt32 i = 0; i < m_cFoodPos.size(); ++i) {
//        Real randomX = m_pcRNG->Uniform(m_cForagingArenaSideX);
//        Real randomY = m_pcRNG->Uniform(m_cForagingArenaSideY);
//
//        // Add a new food with an LED on top
//        CBoxEntity* pcBox = new CBoxEntity("food" + i,                  // id
//                                           CVector3(randomX, randomY, 0.0), // position
//                                           CQuaternion(),           // orientation
//                                           true,                    // movable or not?
//                                           CVector3(0.5, 0.5, 0.5), // size
//                                           1.0);
//        // Add the box to the simulation
//        AddEntity(*pcBox);
//
//        // Enable LED management for the box
////        pcBox->EnableLEDs(cLEDMedium);
//        // Add LED on top of the box
////        pcBox->AddLED(CVector3(0.0, 0.0, 1.0), // offset
////                      CColor::RED);            // color
//
//        m_cFoodPos[i] = pcBox;
//    }
//}


void CEpuckAggregationLoopFunctions::Reset() {
}

/****************************************/
/****************************************/

void CEpuckAggregationLoopFunctions::Destroy() {
}

/****************************************/
/****************************************/

CColor CEpuckAggregationLoopFunctions::GetFloorColor(const CVector2& c_position_on_plane) {
   if(c_position_on_plane.GetX() < -1.0f) {
      return CColor::GRAY50;
   }
//   for(UInt32 i = 0; i < m_cFoodPos.size(); ++i) {
//      if((c_position_on_plane - m_cFoodPos[i]).SquareLength() < m_fFoodSquareRadius) {
//         return CColor::BLACK;
//      }
//   }
   return CColor::WHITE;
}

/****************************************/
/****************************************/

void CEpuckAggregationLoopFunctions::PreStep() {
}

/****************************************/
/****************************************/

REGISTER_LOOP_FUNCTIONS(CEpuckAggregationLoopFunctions, "epuck_aggregation_loop_functions")
